==> agconnect_clouddb-1.3.0%2B300.tar.gz: example/README.md <==
# AGC CloudDB Flutter Demo

## Contents

- [1. Introduction](#1-introduction)
- [2. Installation Guide](#2-installation-guide)
  - [2.1. Creating a Project in AppGallery Connect](#21-creating-a-project-in-appgallery-connect)
  - [2.2. Obtaining agconnect-services.json and agconnect-services.plist](#22-obtaining-agconnect-servicesjson-and-agconnect-servicesplist)
  - [2.3. Build & Run the project](#23-build-&-run-the-project)
- [3. Configuration and Description](#3-configuration-and-description)
- [4. FAQs](#4-faqs)
- [5. Licencing and Terms](#5-licencing-and-terms)

---

## 1. Introduction

This demo application demonstrates the usage of AGC CloudDB Flutter plugin.

---

## 2. Installation Guide

Before you get started, you must register as a HUAWEI Developer and complete identity verification on the [HUAWEI Developer](https://developer.huawei.com/consumer/en/?ha_source=hms1) website. For details, please refer to [Register a HUAWEI ID](https://developer.huawei.com/consumer/en/doc/10104?ha_source=hms1).

### 2.1. Creating a Project in AppGallery Connect

Creating an app in AppGallery Connect is required in order to communicate with the Huawei services. To create an app, perform the following steps:

1. Sign in to [AppGallery Connect](https://developer.huawei.com/consumer/en/service/josp/agc/index.html?ha_source=hms1) and select **My projects**.
2. Select your project from the project list or create a new one by clicking the **Add Project** button.
3. Go to **Project settings** > **General information**, and click **Add app**.
   If an app exists in the project and you need to add a new one, expand the app selection area on the top of the page and click **Add app**.
4. On the **Add app** page, enter the app information, and click **OK**.

### 2.2. Obtaining agconnect-services.json and agconnect-services.plist

1. Sign in to [AppGallery Connect](https://developer.huawei.com/consumer/en/service/josp/agc/index.html?ha_source=hms1) and select your project from **My Projects**. Then go to **Project settings** > **General information**. In the **App information** field,
   
   - If platform is Android, click **agconnect-services.json** button to download the configuration file.
   - If platform is iOS, click **agconnect-services.plist** button to download the configuration file.

### 2.3 Build & Run the project

**Step 1:** Run the following command to update package info.

```
[project_path]> flutter pub get
```

**Step 2:** Run the following command to start the demo app.

```
[project_path]> flutter run
```

---

## 3. Configuration and Description
No.

---

## 4. FAQs

### Why is the message 'google/protobuf/any.h' file not found file not found displayed when I run pod install?
Protobuf-C++ causes the problem.

You can fix this problem by following the steps below.

1. Select 'Pods'

2. Select 'Protobuf-C++'

3. Select 'Build Settings'

4. Search 'search path'

5. Select 'Header Search Paths'

6. Add '$(SRCROOT)/Protobuf-C++/src'

---
 
## 5. Licencing and Terms

AGC Cloud DB Flutter Plugin is licensed under the [Apache 2.0 license](LICENCE).

==> agconnect_clouddb-1.5.0%2B300.tar.gz: example/README.md <==
# AppGallery Connect Cloud DB Flutter Demo

## Contents

- [1. Introduction](#1-introduction)
- [2. Installation Guide](#2-installation-guide)
  - [2.1. Creating a Project in AppGallery Connect](#21-creating-a-project-in-appgallery-connect)
  - [2.2. Obtaining agconnect-services.json and agconnect-services.plist](#22-obtaining-agconnect-servicesjson-and-agconnect-servicesplist)
  - [2.3. Build & Run the project](#23-build-&-run-the-project)
- [3. Configuration and Description](#3-configuration-and-description)
- [4. FAQs](#4-faqs)
- [5. Licencing and Terms](#5-licencing-and-terms)

---

## 1. Introduction

This demo application demonstrates the usage of AppGallery Connect Cloud DB Flutter plugin.

---

## 2. Installation Guide

Before you get started, you must register as a HUAWEI Developer and complete identity verification on the [HUAWEI Developer](https://developer.huawei.com/consumer/en/?ha_source=hms1) website. For details, please refer to [Register a HUAWEI ID](https://developer.huawei.com/consumer/en/doc/10104?ha_source=hms1).

### 2.1. Creating a Project in AppGallery Connect

Creating an app in AppGallery Connect is required in order to communicate with the Huawei services. To create an app, perform the following steps:

1. Sign in to [AppGallery Connect](https://developer.huawei.com/consumer/en/service/josp/agc/index.html?ha_source=hms1) and select **My projects**.
2. Select your project from the project list or create a new one by clicking the **Add Project** button.
3. Go to **Project settings** > **General information**, and click **Add app**.
   If an app exists in the project and you need to add a new one, expand the app selection area on the top of the page and click **Add app**.
4. On the **Add app** page, enter the app information, and click **OK**.

### 2.2. Obtaining agconnect-services.json and agconnect-services.plist

1. Sign in to [AppGallery Connect](https://developer.huawei.com/consumer/en/service/josp/agc/index.html?ha_source=hms1) and select your project from **My Projects**. Then go to **Project settings** > **General information**. In the **App information** field,
   
   - If platform is Android, click **agconnect-services.json** button to download the configuration file.
   - If platform is iOS, click **agconnect-services.plist** button to download the configuration file.

### 2.3 Build & Run the project

**Step 1:** Run the following command to update package info.

```
[project_path]> flutter pub get
```

**Step 2:** Run the following command to start the demo app.

```
[project_path]> flutter run
```

---

## 3. Configuration and Description
No.

---

## 4. FAQs

### Why is the message 'google/protobuf/any.h' file not found file not found displayed when I run pod install?
Protobuf-C++ causes the problem.

You can fix this problem by following the steps below.

1. Select 'Pods'

2. Select 'Protobuf-C++'

3. Select 'Build Settings'

4. Search 'search path'

5. Select 'Header Search Paths'

6. Add '$(SRCROOT)/Protobuf-C++/src'

---
 
## 5. Licencing and Terms

AppGallery Connect Cloud DB Flutter Plugin is licensed under the [Apache 2.0 license](LICENCE).
